#!/usr/bin/env python3
# -*- coding: utf-8 -*-


"""
App info, license, version
Python 3.8+
Date created: June 14th, 2020
Date modified: August 6th, 2021
"""

VERSION = '0.2.0'


def app_info():
    """
    Show app infos (Version & License)
    """
    print('\n\n    ##### A Python script to read iMessage data #####')
    print('    #              Created by niftycode             #')
    print(f'    #                 Version {VERSION}                 #')
    print('    #                  MIT License                  #')
    print('    #################################################\n\n')
    print()
